@@ -2414,16 +2414,8 @@ errno_t e_adjtime(struct timeval *delta, struct timeval *olddelta)
 {
 	errno_t err;
 	kern_return_t kr;
-	integer_t rv[2];
 
-	struct {
-		struct timeval *delta;
-		struct timeval *olddelta;
-	} a;
-	a.olddelta = olddelta;
-	a.delta = delta;
-
-	kr = emul_generic(process_self(), SYS_adjtime, &a, &rv);
+	kr = bsd_adjtime(process_self(), *delta, olddelta);
 	err = kr ? e_mach_error_to_errno(kr) : 0;
 	return err;
 }
@@ -2674,80 +2666,42 @@ errno_t e_swapon(const char *special)
 
 errno_t e_gethostname(char *name, int namelen)
 {
-	/* USE SYSCTL */
+	int    mib[2];
+	size_t size;
 
-	errno_t err;
-	kern_return_t kr;
-	integer_t rv[2];
-
-	struct {
-		char *name;
-		int namelen;
-	} a;
-	a.namelen = namelen;
-	a.name = name;
-
-	kr = emul_generic(process_self(), SYS_ogethostname, &a, &rv);
-	err = kr ? e_mach_error_to_errno(kr) : 0;
-	return err;
+	mib[0] = CTL_KERN;
+	mib[1] = KERN_HOSTNAME;
+	size = namelen;
+	return e_sysctl(mib, 2, (void *)name, &size, NULL, 0, 0);
 }
 
 errno_t e_sethostname(const char *name, int namelen)
 {
-	/* USE SYSCTL */
+	int mib[2];
 
-	errno_t err;
-	kern_return_t kr;
-	integer_t rv[2];
-
-	struct {
-		const char *name;
-		int namelen;
-	} a;
-	a.namelen = namelen;
-	a.name = name;
-
-	kr = emul_generic(process_self(), SYS_osethostname, &a, &rv);
-	err = kr ? e_mach_error_to_errno(kr) : 0;
-	return err;
+	mib[0] = CTL_KERN;
+	mib[1] = KERN_HOSTNAME;
+	return e_sysctl(mib, 2, NULL, NULL, (void *)name, (size_t)namelen, 0);
 }
 
 errno_t e_gethostid(int *id)
 {
-	/* USE SYSCTL */
+	int    mib[2];
+	size_t size;
 
-	errno_t err;
-	kern_return_t kr;
-	integer_t rv[2];
-
-	struct {
-		integer_t dummy;
-	} a;
-
-	kr = emul_generic(process_self(), SYS_ogethostid, &a, &rv);
-	err = kr ? e_mach_error_to_errno(kr) : 0;
-	if (err == 0)
-		*id = rv[0];
-	return err;
+	mib[0] = CTL_KERN;
+	mib[1] = KERN_HOSTID;
+	size = sizeof(int);
+	return e_sysctl(mib, 2, (void *)id, &size, NULL, 0, 0);
 }
 
 errno_t e_sethostid(int hostid)
 {
-	/* USE SYSCTL */
-
-	errno_t err;
-	kern_return_t kr;
-	integer_t rv[2];
-
-	union {
-		int hostid;
-		integer_t dummy;
-	} a;
-	a.hostid = hostid;
-
-	kr = emul_generic(process_self(), SYS_osethostid, &a, &rv);
-	err = kr ? e_mach_error_to_errno(kr) : 0;
-	return err;
+	int mib[2];
+	
+	mib[0] = CTL_KERN;
+	mib[1] = KERN_HOSTID;
+	return e_sysctl(mib, 2, NULL, NULL, (void *)&hostid, sizeof (int), 0);
 }
 
 errno_t e_table(int id, int index, char *addr, int nel, u_int lel, int *cel)
@@ -2809,31 +2763,37 @@ errno_t e_sysctrace(pid_t pid)
 }
 
 errno_t e_sysctl(int *name, unsigned int namelen, void *old, size_t *oldlenp,
-		   void *new, size_t newlen, int *retlen)
+		 void *new, size_t newlen, int *retlen)
 {
-	errno_t err;
-	kern_return_t kr;
-	integer_t rv[2];
+	errno_t                 err;
+	kern_return_t           kr;
+	void                   *ret;
+	mach_msg_type_number_t  ret_count;
+	size_t                  oldlen;
+	int                     rv;
 
-	struct {
-		int *name;
-		unsigned int namelen;
-		void *old;
-		size_t *oldlenp;
-		void *new;
-		size_t newlen;
-	} a;
-	a.name = name;
-	a.namelen = namelen;
-	a.old = old;
-	a.oldlenp = oldlenp;
-	a.new = new;
-	a.newlen = newlen;
-
-	kr = emul_generic(process_self(), SYS___sysctl, &a, &rv);
+	oldlen = oldlenp ? *oldlenp : 0;
+	/*
+	 * XXX If the user gives NULL old, and non-NULL oldlenp and *oldlenp
+	 * is not zero, fix the actual parameter given to the server.
+	 */
+	if (old == 0 && oldlenp && *oldlenp != 0)
+		oldlen = 0;
+	kr = bsd_sysctl(process_self(), name, namelen, namelen,
+			&ret, &ret_count, &oldlen, new, newlen, newlen, &rv);
 	err = kr ? e_mach_error_to_errno(kr) : 0;
-	if (retlen && err == 0)
-	    *retlen = rv[0];
+	if (err == 0) {
+		if (retlen)
+			*retlen = rv;
+		if (old && rv)
+			bcopy(ret, old, rv);
+		if (oldlenp)
+			*oldlenp = oldlen;
+		if (ret_count)
+			(void)vm_deallocate(mach_task_self(),
+					    (vm_offset_t)ret,
+					    (vm_size_t)ret_count);
+	}
 	return err;
 }
 
