@@ -160,7 +160,7 @@ errno_t emul_exec_open(
 					 mach_error_string(err));
 			return ENOEXEC;
 		}
-		bcopy(mapped_addr, hdr, sizeof(*hdr));
+		bcopy((void *)mapped_addr, hdr, sizeof(*hdr));
 		err = vm_deallocate(mach_task_self(), mapped_addr,
 				    mapped_size);
 		if (err != KERN_SUCCESS) {
@@ -352,7 +352,7 @@ errno_t e_obreak(const char *addr, char **retval)
 		heap_end -= (old - new);
 	}
 	if (retval)
-	    *retval = addr ? addr : (char *) heap_end;
+	    *retval = addr ? (char *) addr : (char *) heap_end;
 	return ESUCCESS;
 }
 
