@@ -17,7 +17,16 @@
  */
 /*
  * HISTORY
- * $Log: $
+ * $Log: emulator_base.c,v $
+ * Revision 1.3  1995/07/12  00:38:35  sclawson
+ * Added fix for using GNU ld v2.x when compiling for mach UX on the i386.
+ *
+ * Revision 1.2  1995/07/11  21:24:30  sclawson
+ * fixed for gnu ld v.2  on the x86
+ *
+ * Revision 1.1.1.2  1995/03/23  01:15:41  law
+ * lites-950323 from jvh.
+ *
  */
 /* 
  * Print arguments to emulation link command. Some of these are hard
@@ -37,8 +46,15 @@ main() {
 #	elif OSF1
 	printf("-e _start -Ttext %x\n", EMULATOR_BASE + 0x1000);
 #	else
-        /* No 0x here as the old linker makes the address zero! */
+#       ifdef GNU_LD2
+#include <sys/exec.h>
+
+        printf("-e __start -qmagic -Ttext 0x%x\n",
+		 EMULATOR_BASE + sizeof(struct exec) + 0x1000);
+#       else
+	/* No 0x here as the old linker makes the address zero! */
         printf("-e __start -T %x\n", EMULATOR_BASE + 0x1000);
+#	endif
 #	endif
 	return 0;
 }
