@@ -65,6 +65,7 @@
 #include "machid_register.h"
 #include "second_server.h"
 #include "sl.h"
+#include "ppp.h"
 
 #include <serv/server_defs.h>
 #include <sys/param.h>
@@ -299,16 +300,22 @@ noreturn system_setup()
 	for (pdev = pdevinit; pdev->pdev_attach != NULL; pdev++)
 		(*pdev->pdev_attach)(pdev->pdev_count);
 #endif
+	{
+		extern loopattach(int);
+		loopattach(0);			/* XXX */
+	}
 #if NSL > 0
 	{
 		extern slattach(void);
 		slattach();			/* XXX */
 	}
 #endif
+#if NPPP > 0
 	{
-		extern loopattach(int);
-		loopattach(0);			/* XXX */
+		extern pppattach(void);
+		pppattach();			/* XXX */
 	}
+#endif
 	/*
 	 * Start network server thread.
 	 */
