@@ -75,50 +75,43 @@ static struct sysctl_lock {
 	int	sl_locked;
 } memlock;
 
-struct sysctl_args {
-	int	*name;
-	u_int	namelen;
-	void	*old;
-	size_t	*oldlenp;
-	void	*new;
-	size_t	newlen;
-};
-
 int
-__sysctl(p, uap, retval)
-	struct proc *p;
-	register struct sysctl_args *uap;
-	int *retval;
+s___sysctl(
+	struct proc 	*p,
+	int 		*name,
+	u_int		namelen,
+	void 		*old,
+	size_t 		*oldlenp,
+	void 		*new,
+	size_t 		newlen,
+	int 		*retval)
 {
 	int error, dolock = 1;
 	u_int savelen, oldlen = 0;
 	sysctlfn *fn;
-	int name[CTL_MAXNAME];
 
-	if (uap->new != NULL && (error = suser(p->p_ucred, &p->p_acflag)))
+	if (new != NULL && (error = suser(p->p_ucred, &p->p_acflag)))
 		return (error);
 	/*
 	 * all top-level sysctl names are non-terminal
 	 */
-	if (uap->namelen > CTL_MAXNAME || uap->namelen < 2)
+	if (namelen > CTL_MAXNAME || namelen < 2)
 		return (EINVAL);
-	if (error = copyin(uap->name, &name, uap->namelen * sizeof(int)))
-		return (error);
 
 	switch (name[0]) {
 	case CTL_KERN:
 		fn = kern_sysctl;
+#ifndef LITES			/* XXX */
 		if (name[2] != KERN_VNODE)	/* XXX */
 			dolock = 0;
+#endif
 		break;
 	case CTL_HW:
 		fn = hw_sysctl;
 		break;
-#ifndef LITES
 	case CTL_VM:
 		fn = vm_sysctl;
 		break;
-#endif
 	case CTL_NET:
 		fn = net_sysctl;
 		break;
@@ -139,12 +132,9 @@ __sysctl(p, uap, retval)
 		return (EOPNOTSUPP);
 	}
 
-	if (uap->oldlenp &&
-	    (error = copyin(uap->oldlenp, &oldlen, sizeof(oldlen))))
-		return (error);
-	if (uap->old != NULL) {
-		if (!useracc(uap->old, oldlen, B_WRITE))
-			return (EFAULT);
+	if (oldlenp)
+		oldlen = *oldlenp;
+	if (old != NULL) {
 		while (memlock.sl_lock) {
 			memlock.sl_want = 1;
 			sleep((caddr_t)&memlock, PRIBIO+1);
@@ -153,16 +143,15 @@ __sysctl(p, uap, retval)
 		memlock.sl_lock = 1;
 #ifndef LITES			/* XXX */
 		if (dolock)
-			vslock(uap->old, oldlen);
-#endif
+			vslock(old, oldlen);
 		savelen = oldlen;
+#endif
 	}
-	error = (*fn)(name + 1, uap->namelen - 1, uap->old, &oldlen,
-	    uap->new, uap->newlen, p);
-	if (uap->old != NULL) {
+	error = (*fn)(name + 1, namelen - 1, old, &oldlen, new, newlen, p);
+	if (old != NULL) {
 #ifndef LITES			/* XXX */
 		if (dolock)
-			vsunlock(uap->old, savelen, B_WRITE);
+			vsunlock(old, savelen, B_WRITE);
 #endif
 		memlock.sl_lock = 0;
 		if (memlock.sl_want) {
@@ -172,8 +161,8 @@ __sysctl(p, uap, retval)
 	}
 	if (error)
 		return (error);
-	if (uap->oldlenp)
-		error = copyout(&oldlen, uap->oldlenp, sizeof(oldlen));
+	if (oldlenp)
+		*oldlenp = oldlen;
 	*retval = oldlen;
 	return (0);
 }
@@ -249,7 +238,7 @@ kern_sysctl(name, namelen, oldp, oldlenp, newp, newlen, p)
 		return (error);
 	case KERN_HOSTID:
 		inthostid = hostid;  /* XXX assumes sizeof long <= sizeof int */
-		error =  sysctl_int(oldp, oldlenp, newp, newlen, &inthostid);
+		error = sysctl_int(oldp, oldlenp, newp, newlen, &inthostid);
 		hostid = inthostid;
 		return (error);
 #ifndef LITES			/* XXX not yet */
@@ -312,7 +301,7 @@ hw_sysctl(name, namelen, oldp, oldlenp, newp, newlen, p)
 	case HW_MACHINE:
 		return (sysctl_rdstring(oldp, oldlenp, newp, machine));
 #ifdef LITES
-#else /LITES */
+#else /*LITES */
 	case HW_MODEL:
 		return (sysctl_rdstring(oldp, oldlenp, newp, cpu_model));
 #endif
@@ -335,6 +324,60 @@ hw_sysctl(name, namelen, oldp, oldlenp, newp, newlen, p)
 	/* NOTREACHED */
 }
 
+#ifdef LITES
+
+/*
+ * CTL_VM identifiers
+ */
+#define VM_METER        1               /* struct vmmeter */
+#define VM_LOADAVG      2               /* struct loadavg */
+#define VM_MAXID        3               /* number of valid vm ids */
+
+/*
+ * Attributes associated with virtual memory.
+ */
+vm_sysctl(name, namelen, oldp, oldlenp, newp, newlen, p)
+	int *name;
+	u_int namelen;
+	void *oldp;
+	size_t *oldlenp;
+	void *newp;
+	size_t newlen;
+	struct proc *p;
+{
+	struct loadavg        averunnable;
+	extern mach_port_t    host_port;
+	host_load_info_data_t load_info;
+	int                   count = HOST_LOAD_INFO_COUNT;
+	
+	/* all sysctl names at this level are terminal */
+	if (namelen != 1)
+		return (ENOTDIR);		/* overloaded */
+
+	switch (name[0]) {
+	case VM_LOADAVG:
+		(void) host_info(host_port, HOST_LOAD_INFO,
+				 (host_info_t)&load_info,
+				 (mach_msg_type_number_t *)&count);
+		averunnable.ldavg[0] = load_info.avenrun[0];
+		averunnable.ldavg[1] = load_info.avenrun[1];
+		averunnable.ldavg[2] = load_info.avenrun[2];
+		averunnable.fscale = LOAD_SCALE;
+		return (sysctl_rdstruct(oldp, oldlenp, newp, &averunnable,
+		    sizeof(averunnable)));
+#if 0
+	case VM_METER:
+		vmtotal(&vmtotals);
+		return (sysctl_rdstruct(oldp, oldlenp, newp, &vmtotals,
+		    sizeof(vmtotals)));
+#endif
+	default:
+		return (EOPNOTSUPP);
+	}
+	/* NOTREACHED */
+}
+#endif
+
 #ifdef DEBUG
 /*
  * Debugging related system variables.
@@ -398,9 +441,9 @@ sysctl_int(oldp, oldlenp, newp, newlen, valp)
 		return (EINVAL);
 	*oldlenp = sizeof(int);
 	if (oldp)
-		error = copyout(valp, oldp, sizeof(int));
+		*(int *)oldp = *(int *)valp;
 	if (error == 0 && newp)
-		error = copyin(newp, valp, sizeof(int));
+		*(int *)valp = *(int *)newp;
 	return (error);
 }
 
@@ -421,7 +464,7 @@ sysctl_rdint(oldp, oldlenp, newp, val)
 		return (EPERM);
 	*oldlenp = sizeof(int);
 	if (oldp)
-		error = copyout((caddr_t)&val, oldp, sizeof(int));
+		*(int *)oldp = val;
 	return (error);
 }
 
@@ -446,10 +489,10 @@ sysctl_string(oldp, oldlenp, newp, newlen, str, maxlen)
 		return (EINVAL);
 	if (oldp) {
 		*oldlenp = len;
-		error = copyout(str, oldp, len);
+		bcopy(str, oldp, len);
 	}
 	if (error == 0 && newp) {
-		error = copyin(newp, str, newlen);
+		bcopy(newp, str, newlen);
 		str[newlen] = 0;
 	}
 	return (error);
@@ -473,7 +516,7 @@ sysctl_rdstring(oldp, oldlenp, newp, str)
 		return (EPERM);
 	*oldlenp = len;
 	if (oldp)
-		error = copyout(str, oldp, len);
+		bcopy(str, oldp, len);
 	return (error);
 }
 
@@ -497,10 +540,10 @@ sysctl_struct(oldp, oldlenp, newp, newlen, sp, len)
 		return (EINVAL);
 	if (oldp) {
 		*oldlenp = len;
-		error = copyout(sp, oldp, len);
+		bcopy(sp, oldp, len);
 	}
 	if (error == 0 && newp)
-		error = copyin(newp, sp, len);
+		bcopy(newp, sp, len);
 	return (error);
 }
 
@@ -522,7 +565,7 @@ sysctl_rdstruct(oldp, oldlenp, newp, sp, len)
 		return (EPERM);
 	*oldlenp = len;
 	if (oldp)
-		error = copyout(sp, oldp, len);
+		bcopy(sp, oldp, len);
 	return (error);
 }
 
@@ -553,8 +596,7 @@ sysctl_file(where, sizep)
 		*sizep = 0;
 		return (0);
 	}
-	if (error = copyout((caddr_t)&filehead, where, sizeof(filehead)))
-		return (error);
+	bcopy((caddr_t)&filehead, where, sizeof(filehead));
 	buflen -= sizeof(filehead);
 	where += sizeof(filehead);
 
@@ -566,8 +608,7 @@ sysctl_file(where, sizep)
 			*sizep = where - start;
 			return (ENOMEM);
 		}
-		if (error = copyout((caddr_t)fp, where, sizeof (struct file)))
-			return (error);
+		bcopy((caddr_t)fp, where, sizeof (struct file));
 		buflen -= sizeof(struct file);
 		where += sizeof(struct file);
 	}
@@ -642,12 +683,8 @@ again:
 		}
 		if (buflen >= sizeof(struct kinfo_proc)) {
 			fill_eproc(p, &eproc);
-			if (error = copyout((caddr_t)p, &dp->kp_proc,
-			    sizeof(struct proc)))
-				return (error);
-			if (error = copyout((caddr_t)&eproc, &dp->kp_eproc,
-			    sizeof(eproc)))
-				return (error);
+			bcopy((caddr_t)p, &dp->kp_proc, sizeof (struct proc));
+			bcopy((caddr_t)&eproc, &dp->kp_eproc, sizeof (eproc));
 			dp++;
 			buflen -= sizeof(struct kinfo_proc);
 		}
@@ -795,12 +832,12 @@ ogetkerninfo(p, uap, retval)
 		name[0] = VM_METER;
 		error = vm_sysctl(name, 1, uap->where, &size, NULL, 0, p);
 		break;
+#endif /* LITES */
 
 	case KINFO_LOADAVG:
 		name[0] = VM_LOADAVG;
 		error = vm_sysctl(name, 1, uap->where, &size, NULL, 0, p);
 		break;
-#endif /* LITES */
 
 	case KINFO_CLOCKRATE:
 		name[0] = KERN_CLOCKRATE;
