@@ -17,7 +17,14 @@
  */
 /*
  * HISTORY
- * $Log: $
+ * $Log: subr_prf.c,v $
+ * Revision 1.4  1995/07/12  16:39:58  mike
+ * actually return a value from dgetc
+ *
+ * Revision 1.3  1995/03/23  01:44:40  law
+ * Update to 950323 snapshot + utah changes
+ *
+ *
  */
 /* 
  *	File:	 subr_prf.c
@@ -101,8 +108,20 @@
 
 struct	tty *constty;			/* pointer to console "window" tty */
 
+#ifdef parisc
+/* Should be a configuration option */
+#define PUTCTRAP 1
+#else
+#define PUTCTRAP 0
+#endif
+
+#if PUTCTRAP
+extern	cntrap();		/* standard console putc */
+int	(*v_putc)() = cntrap;	/* routine to putc on virtual console */
+#else
 extern	cnputc();		/* standard console putc */
 int	(*v_putc)() = cnputc;	/* routine to putc on virtual console */
+#endif
 
 void  logpri __P((int level));
 static void  putchar __P((int ch, int flags, struct tty *tp));
@@ -506,6 +525,16 @@ static void putchar(
 {
 	extern int msgbufmapped;
 	register struct msgbuf *mbp;
+#if defined(SECOND_SERVER) && PUTCTRAP
+	static int first = 1;
+	extern cnputc();
+
+	if (first) {
+		first = 0;
+		if (second_server)
+		    v_putc = cnputc;
+	}
+#endif
 
 	if (panicstr)
 		constty = NULL;
@@ -531,6 +560,30 @@ static void putchar(
 		(*v_putc)(c);
 }
 
+#if PUTCTRAP
+/* Should be in MD file */
+cntrap(c)
+       int c;
+{
+	asm volatile("
+		copy    %0,%%r26
+		ldi     -1,%%r25
+		break   0,6"
+		: : "r" (c));
+}
+
+cnputs(str, len)
+	char *str;
+	int len;
+{
+	asm volatile("
+		copy    %0,%%r26
+		copy    %1,%%r25
+		break   0,6"
+		: : "r" (str), "r" (len));
+}
+#endif
+
 /*
  * Scaled down version of sprintf(3).
  */
@@ -734,6 +787,9 @@ dprintf(const char *fmt, ...)
 	len = vsprintf(bp, fmt, ap);
 	va_end(ap);
 
+#if PUTCTRAP
+	cnputs(dprintf_buf, len);
+#else
 	bp = dprintf_buf;
 	if (dprintf_buf[len] == '\n')
 	  dprintf_buf[ ++len ] = '\r';
@@ -745,16 +801,17 @@ dprintf(const char *fmt, ...)
 	    bp  += done;
 	    len -= done;
 	}
+#endif
 }
 
 dgetc()
 {
-	int len;
+	mach_msg_type_number_t len;
 	io_buf_ptr_inband_t chr;
 	kern_return_t	rc;
 
 	if (!dprintf_initted) {
-		if (! device_server_port) return;
+		if (! device_server_port) return -1;
 		dprintf_initted = 1;
 		/*
 		 * Open the console
@@ -770,47 +827,52 @@ dgetc()
 				 "console",
 				 &dprintf_console_port);
 		if (rc != KERN_SUCCESS)
-		    panic("gets: console_init");
+			panic("dgetc: console_init");
 	}
-
-	 rc = device_read_inband(dprintf_console_port, 0, 0, 1,
-			chr,
-			(mach_msg_type_number_t *) &len);
-	if (rc != KERN_SUCCESS)
-	    panic("gets: device_read_inband");
-
+	len = 1;
+	rc = device_read_inband(dprintf_console_port,
+				(dev_mode_t)0, (recnum_t)0, 1,
+				chr, &len);
+	if (rc != KERN_SUCCESS) {
+		panic("dgetc: device_read_inband %x %s",
+		      rc, mach_error_string(rc));
+		return -1;
+	}
+	return (len == 1) ? chr[0] : -1;
 }
 
 /* Prompt on console and read string.  size includes nul */
 dget_string(const char *prompt, char *buf, int size)
 {
-  int count = 0;
-  int c;
-
-  if (prompt)
-    dprintf(prompt);
-
-  while (count < size) {
-    c = dgetc();
-    switch (c) {
-    case '.':
-    case '\n':
-    case '\r':
-      buf[count] = '\0';
-      return;
-    case '\b':
-    case '\177':
-      if (count <= 0)
-	continue;
-      dprintf("\b \b");
-      count--;
-      break;
-    default:
-      buf[count] = c;
-      dprintf("%c", c);
-      count++;
-      break;
-    }
-  }
-  buf[count] = '\0';
+	int count = 0;
+	int c;
+	
+	if (prompt)
+		dprintf(prompt);
+	
+	while (count < size) {
+		c = dgetc();
+		switch (c) {
+		case -1:
+		case '.':
+		case '\n':
+		case '\r':
+			dprintf("\n\r");
+			buf[count] = '\0';
+			return;
+		case '\b':
+		case '\177':
+			if (count <= 0)
+				continue;
+			dprintf("\b \b");
+			count--;
+			break;
+		default:
+			buf[count] = c;
+			dprintf("%c", c);
+			count++;
+			break;
+		}
+	}
+	buf[count] = '\0';
 }
