@@ -217,7 +217,9 @@ void vattr_null(vap)
 {
 
 	vap->va_type = VNON;
-	vap->va_size = vap->va_bytes = VNOVAL;
+        /* XXX These next two used to be one line, but for a GCC bug. */
+	vap->va_size = VNOVAL;
+	vap->va_bytes = VNOVAL;
 	vap->va_mode = vap->va_nlink = vap->va_uid = vap->va_gid =
 		vap->va_fsid = vap->va_fileid =
 		vap->va_blocksize = vap->va_rdev =
@@ -292,7 +294,6 @@ getnewvnode(tag, mp, vops, vpp)
 	cache_purge(vp);
 	vp->v_tag = tag;
 	vp->v_op = vops;
-	insmntque(vp, mp);
 	*vpp = vp;
 	vp->v_usecount = 1;
 	vp->v_data = 0;
@@ -504,6 +505,7 @@ bdevvp(dev, vpp)
 		return (error);
 	}
 	vp = nvp;
+	insmntque(vp, 0);
 	vp->v_type = VBLK;
 	if (nvp = checkalias(vp, dev, (struct mount *)0)) {
 		vput(vp);
@@ -1132,9 +1134,14 @@ again:
 				*sizep = bp - where;
 				return (ENOMEM);
 			}
+#ifndef LITES
 			if ((error = copyout((caddr_t)&vp, bp, VPTRSZ)) ||
 			   (error = copyout((caddr_t)vp, bp + VPTRSZ, VNODESZ)))
 				return (error);
+#else
+			bcopy((caddr_t)&vp, bp, VPTRSZ);
+			bcopy((caddr_t)vp, bp + VPTRSZ, VNODESZ);
+#endif
 			bp += VPTRSZ + VNODESZ;
 		}
 		vfs_unbusy(mp);
