@@ -24,7 +24,13 @@
  *	New physmem and host_basic_info files.
  *	Fixed loadavg to use host_info() and to print Mach factors on
  *	a second line.
- * $Log: $
+ * $Log: kernfs_vnops.c,v $
+ * Revision 1.2  1995/06/25  04:16:48  law
+ * Install fix for "update race in 4.4 filesystme code"
+ *
+ * Revision 1.1.1.1  1995/03/02  21:49:49  mike
+ * Initial Lites release from hut.fi
+ *
  */
 /* 
  *	File:	server/miscfs/kernfs/kernfs_vnops.c
@@ -352,6 +358,8 @@ mach_error_t kernfs_lookup(ap)
 		goto bad;
 	MALLOC(fvp->v_data, void *, sizeof(struct kernfs_node), M_TEMP, M_WAITOK);
 	VTOKERN(fvp)->kf_kt = &kern_targets[i];
+	insmntque(fvp, dvp->v_mount);
+
 	fvp->v_type = VTOKERN(fvp)->kf_kt->kt_vtype;
 	*vpp = fvp;
 #ifdef KERNFS_DIAGNOSTIC
