@@ -696,10 +696,15 @@ sysctl_dumpentry(rn, w)
 		rtm->rtm_index = rt->rt_ifp->if_index;
 		rtm->rtm_errno = rtm->rtm_pid = rtm->rtm_seq = 0;
 		rtm->rtm_addrs = info.rti_addrs;
+#ifndef LITES
 		if (error = copyout((caddr_t)rtm, w->w_where, size))
 			w->w_where = NULL;
 		else
 			w->w_where += size;
+#else
+		bcopy((caddr_t)rtm, w->w_where, size);
+		w->w_where += size;
+#endif
 	}
 	return (error);
 }
@@ -730,8 +735,12 @@ sysctl_iflist(af, w)
 			ifm->ifm_flags = ifp->if_flags;
 			ifm->ifm_data = ifp->if_data;
 			ifm->ifm_addrs = info.rti_addrs;
+#ifndef LITES
 			if (error = copyout((caddr_t)ifm, w->w_where, len))
 				return (error);
+#else
+			bcopy((caddr_t)ifm, w->w_where, len);
+#endif
 			w->w_where += len;
 		}
 		while (ifa = ifa->ifa_next) {
@@ -749,8 +758,12 @@ sysctl_iflist(af, w)
 				ifam->ifam_flags = ifa->ifa_flags;
 				ifam->ifam_metric = ifa->ifa_metric;
 				ifam->ifam_addrs = info.rti_addrs;
+#ifndef LITES
 				if (error = copyout(w->w_tmem, w->w_where, len))
 					return (error);
+#else
+				bcopy(w->w_tmem, w->w_where, len);
+#endif
 				w->w_where += len;
 			}
 		}
