@@ -574,27 +574,6 @@ bsd_setitimer(
 	END_SERVER(SYS_setitimer)
 }
 
-kern_return_t
-bsd_sethostname(
-	mach_port_t		proc_port,
-	mach_port_seqno_t	seqno,
-	char			*hostname,
-	int			len)
-{
-	START_SERVER(SYS_osethostname, 2)
-
-	arg[0] = (integer_t)hostname;
-	arg[1] = len;
-
-#if COMPAT_43
-	error = osethostname(p, arg, 0);;
-#else
-	return ENOSYS;
-#endif
-
-	END_SERVER(SYS_osethostname)
-}
-
 kern_return_t
 bsd_bind(
 	mach_port_t		proc_port,
@@ -1315,7 +1294,59 @@ bsd_recvmsg_long(
 			error = s_recvmsg(p, fileno, flags, &outflags,
 					  from, from_count, cmsg, cmsg_count,
 					  *data, datalen, nreceived);
+			if (error)
+				(void)vm_deallocate(mach_task_self(),
+						    (vm_offset_t)*data,
+						    (vm_size_t)*data_count);
 		}
 	}
-	END_SERVER_DEALLOC_ON_ERROR(SYS_recvmsg, (*data), (*data_count));
+	END_SERVER(SYS_recvmsg);
+}
+
+kern_return_t
+bsd_sysctl(
+	mach_port_t		proc_port,
+	mach_port_seqno_t	seqno,
+	mib_t			name,
+	mach_msg_type_number_t  name_count,
+	int                     namelen,
+	char_array              *old,		/* OUT dealloc */
+	mach_msg_type_number_t  *old_count,
+	size_t                  *oldlen, 	/* IN/OUT */
+	char_array              new,		/* IN */
+	mach_msg_type_number_t  new_count,
+	size_t                  newlen,         /* IN */
+	int                     *retlen)        /* OUT */
+{
+	START_SERVER(SYS___sysctl, 6);
+
+	error = KERN_SUCCESS;
+	if (namelen < 2 || namelen > name_count)
+		error = EINVAL;
+	if (error == KERN_SUCCESS) {
+		if (oldlen && *oldlen) {
+			*old_count = round_page(*oldlen);
+			error = vm_allocate(mach_task_self(),
+					    (vm_offset_t *)old,
+					    (vm_size_t)*old_count, TRUE);
+		} else {
+			*old_count = 0;
+			*old       = 0;
+		}
+		if (error == KERN_SUCCESS) {
+			error = s___sysctl(p,
+					   (int *)name, namelen,
+					   (void *)*old, oldlen,
+					   (void *)new, newlen,
+					   retlen);
+			if (error && *old_count)
+				(void)vm_deallocate(mach_task_self(),
+						    (vm_offset_t)*old,
+						    (vm_size_t)*old_count);
+		}
+	}
+	if (new_count)
+		(void)vm_deallocate(mach_task_self(),
+				    (vm_offset_t)new, (vm_size_t)new_count);
+	END_SERVER(SYS___sysctl);
 }
