@@ -27,6 +27,9 @@
  *
  *	Device interface for out-of-kernel kernel.
  */
+
+#include "osfmach3.h"
+
 #include <serv/server_defs.h>
 
 #include <sys/param.h>
@@ -84,7 +87,11 @@ int	char_select_write_reply();	/* forward */
  */
 mach_error_t char_open(dev_t dev, int flag, int devtype, struct proc *p)
 {
+#if OSFMACH3
+	dev_name_t	name;
+#else
 	char		name[32];
+#endif
 	kern_return_t	rc;
 	mach_port_t	device_port;
 	int		mode;
@@ -129,10 +136,15 @@ mach_error_t char_open(dev_t dev, int flag, int devtype, struct proc *p)
 	    if (rc != 0)
 		return (rc);	/* bad name */
 
-	    /* fix modes */
-	    mode = 0;	/* XXX */
+	    mode = D_READ|D_WRITE;
 	    rc = device_open(device_server_port,
+#if OSF_LEDGERS
+			     MACH_PORT_NULL,
+#endif
 			     mode,
+#if OSFMACH3
+			     security_id,
+#endif
 			     name,
 			     &device_port);
 	    if (rc != D_SUCCESS) {
@@ -609,7 +621,10 @@ mach_error_t mmrw(
 			c = iov->iov_len;
 			if (mmca((vm_address_t)uio->uio_offset, (vm_size_t)c,
 			    rw == UIO_READ ? B_READ : B_WRITE)) {
-				error = uiomove((caddr_t)uio->uio_offset,
+			  	/* uio_offset is 64 bit wide */
+			  	vm_offset_t offset =
+				  (vm_offset_t)(uio->uio_offset);
+				error = uiomove((caddr_t)offset,
 					(int)c, uio);
 				continue;
 			}
@@ -650,6 +665,26 @@ boolean_t mmca(
 
     addr = address;
     while (addr < address + count) {
+#if OSFMACH3
+	struct vm_region_basic_info r;
+	mach_msg_type_number_t icount;
+
+	r_addr = addr;
+	icount = VM_REGION_BASIC_INFO_COUNT;
+	if (vm_region(mach_task_self(),
+		      &r_addr,
+		      &r_size,
+		      VM_REGION_BASIC_INFO,
+		      (vm_region_info_t) &r,
+		      &icount,
+		      &r_object_name) != KERN_SUCCESS)
+	    return (0);
+	r_protection = r.protection;
+	r_max_protection = r.max_protection;
+	r_inheritance = r.inheritance;
+	r_is_shared = r.shared;
+	r_offset = r.offset;
+#else
 	r_addr = addr;
 	if (vm_region(mach_task_self(),
 		      &r_addr,
@@ -661,6 +696,7 @@ boolean_t mmca(
 		      &r_object_name,
 		      &r_offset) != KERN_SUCCESS)
 	    return (0);
+#endif /* OSFMACH3 */
 
 	if (MACH_PORT_VALID(r_object_name))
 	    (void) mach_port_deallocate(mach_task_self(), r_object_name);
