@@ -104,7 +104,8 @@ void xxx(s,p,i)
 }
 
 /* XXX Avoid MK83 bug. The page is not protected in the driver queue */
-#define ETHER_SYNCH_OUTPUT 1
+/* XXX Fixed in MK83A */
+/*#define ETHER_SYNCH_OUTPUT 1*/
 
 /*
  * Ethernet trigger routine.
