@@ -248,14 +248,10 @@ mach_error_t tty_open(dev_t dev, int flag, int devtype, struct proc *p)
 	    tp->t_iflag = TTYDEF_IFLAG;
 	    tp->t_oflag = TTYDEF_OFLAG;
 	    tp->t_lflag = TTYDEF_LFLAG;
-#if 0
-	    tp->t_cflag = TTYDEF_CFLAG;  /* was CS8|CREAD;*/
-#else
-	    tp->t_cflag = CS8|CREAD;
-#endif
+	    tp->t_cflag = TTYDEF_CFLAG;
 
-	      rc = tty_param(tp, &tp->t_termios);
-	      if (rc != D_SUCCESS)
+	    rc = tty_param(tp, &tp->t_termios);
+	    if (rc != D_SUCCESS)
 		return(rc);
 
 	    ttsetwater(tp);
